#
# spec file for package libzmf
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libzmf-0_0-0
Name:           libzmf
Version:        0.0.1
Release:        1.3
Summary:        A library for import of Zoner document formats
License:        MPL-2.0
Group:          Productivity/Publishing/Word
Url:            http://wiki.documentfoundation.org/DLP/Libraries/libzmf
Source:         http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM: build with old boost, taken from git
Patch0:         libzmf-old-boost.patch
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
%{name} is a library for generating Zoner documents. It is directly
pluggable into import filters based on librevenge.

%package -n %{libname}
Summary:        An ZMF generator library
Group:          System/Libraries

%description -n %{libname}
%{name} is a library for generating Zoner documents. It is directly
pluggable into import filters based on librevenge.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
%{name} is a library for generating Zoner documents. It is directly
pluggable into import filters based on librevenge.

This package contains the %{name} development files.

%package devel-doc
Summary:        Documentation of %{name} API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
The %{name}-doc package contains documentation files for %{name}.

%package tools
Summary:        Tools for converting the Zoner ZMF files
Group:          Productivity/Publishing/Word

%description tools
Tools to work with the Zoner ZMF files, based on librevenge.

%prep
%setup -q
%patch0 -p1

%build
%configure \
    --disable-werror \
    --disable-static \
    --docdir=%{_docdir}/%{name} \
    --disable-silent-rules
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print
# documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -p AUTHORS COPYING ChangeLog %{buildroot}%{_docdir}/%{name}

%fdupes -s %{buildroot}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
make %{?_smp_mflags} check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/%{name}-*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}-*
%{_libdir}/%{name}-*.so
%{_libdir}/pkgconfig/%{name}-*.pc

%files devel-doc
%defattr(-,root,root,-)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}

%files tools
%defattr(-,root,root,-)
%{_bindir}/*

%changelog
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Jan  4 2017 tchvatal@suse.com
- Add patch to build on older distributions:
  * libzmf-old-boost.patch
* Mon Nov 28 2016 fstrba@suse.com
- Initial package of libzmf 0.0.1
